@@ -18,15 +18,10 @@
 #include <KLocalizedString>
 
 
-K_PLUGIN_FACTORY(KJotsPartFactory, registerPlugin<KJotsPart>();)
+K_PLUGIN_CLASS_WITH_JSON(KJotsPart, "kjotspart.json")
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-KJotsPart::KJotsPart(QWidget *parentWidget, QObject *parent, const QVariantList &)
-    : KParts::ReadOnlyPart(parent)
-#else
 KJotsPart::KJotsPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &data, const QVariantList &)
     : KParts::ReadOnlyPart(parent, data)
-#endif
 {
     // this should be your custom internal widget
     mComponent = new KJotsWidget(parentWidget, this);
@@ -60,3 +55,5 @@ bool KJotsPart::openFile()
 }
 
 #include "kjotspart.moc"
+
+#include "moc_kjotspart.cpp"
