@@ -53,15 +53,9 @@
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/ControlGui>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <grantlee/template.h>
-#include <grantlee/engine.h>
-#include <grantlee/context.h>
-#else
 #include <KTextTemplate/Engine>
 #include <KTextTemplate/Template>
 #include <KTextTemplate/Context>
-#endif
 
 // KDE
 #include <KActionCollection>
@@ -77,7 +71,7 @@
 #include <KIO/OpenUrlJob>
 
 #include <KPIMTextEdit/RichTextComposerActions>
-#include <KPIMTextEdit/RichTextEditorWidget>
+#include <TextCustomEditor/RichTextEditorWidget>
 
 
 // KMime
@@ -99,11 +93,7 @@
 #include <memory>
 
 using namespace Akonadi;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-using namespace Grantlee;
-#else
 using namespace KTextTemplate;
-#endif
 KJotsWidget::KJotsWidget(QWidget *parent, KXMLGUIClient *xmlGuiClient, Qt::WindowFlags f)
     : QWidget(parent, f)
     , m_xmlGuiClient(xmlGuiClient)
@@ -151,7 +141,7 @@ KJotsWidget::KJotsWidget(QWidget *parent, KXMLGUIClient *xmlGuiClient, Qt::Windo
 
     m_orderProxy = new EntityOrderProxyModel(this);
     m_orderProxy->setSourceModel(m_collectionModel);
-    KConfigGroup cfg(KSharedConfig::openConfig(), "KJotsEntityOrder");
+    KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("KJotsEntityOrder"));
     m_orderProxy->setOrderConfig(cfg);
 
     m_collectionView->setModel(m_orderProxy);
@@ -248,7 +238,7 @@ void KJotsWidget::setupGui()
 
     // Editor
     m_editor = new KJotsEdit(m_stackedWidget, m_xmlGuiClient->actionCollection());
-    m_editorWidget = new KPIMTextEdit::RichTextEditorWidget(m_editor, m_stackedWidget);
+    m_editorWidget = new TextCustomEditor::RichTextEditorWidget(m_editor, m_stackedWidget);
     m_editor->setParent(m_editorWidget);
     m_stackedWidget->addWidget(m_editorWidget);
     connect(m_editor, &KJotsEdit::linkClicked, this, &KJotsWidget::openLink);
@@ -270,13 +260,13 @@ void KJotsWidget::restoreState()
     {
         auto saver = new ETMViewStateSaver;
         saver->setView(m_collectionView);
-        KConfigGroup cfg(KSharedConfig::openConfig(), "CollectionViewState");
+        KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("CollectionViewState"));
         saver->restoreState(cfg);
     }
     {
         auto saver = new ETMViewStateSaver;
         saver->setView(m_itemView);
-        KConfigGroup cfg(KSharedConfig::openConfig(), "ItemViewState");
+        KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("ItemViewState"));
         saver->restoreState(cfg);
     }
 }
@@ -286,14 +276,14 @@ void KJotsWidget::saveState()
     {
         ETMViewStateSaver saver;
         saver.setView(m_collectionView);
-        KConfigGroup cfg(KSharedConfig::openConfig(), "CollectionViewState");
+        KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("CollectionViewState"));
         saver.saveState(cfg);
         cfg.sync();
     }
     {
         ETMViewStateSaver saver;
         saver.setView(m_itemView);
-        KConfigGroup cfg(KSharedConfig::openConfig(), "ItemViewState");
+        KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("ItemViewState"));
         saver.saveState(cfg);
         cfg.sync();
     }
@@ -408,7 +398,7 @@ void KJotsWidget::setupActions()
                 m_browserWidget->slotFindNext();
             }
         }, actionCollection);
-    action = KStandardAction::replace(m_editorWidget, &KPIMTextEdit::RichTextEditorWidget::slotReplace, actionCollection);
+    action = KStandardAction::replace(m_editorWidget, &TextCustomEditor::RichTextEditorWidget::slotReplace, actionCollection);
     connect(m_stackedWidget, &QStackedWidget::currentChanged, this, [this, action](int index){
             action->setEnabled(m_stackedWidget->widget(index) == m_editorWidget);
         });
@@ -421,13 +411,14 @@ void KJotsWidget::setupActions()
     bookmarkMenu->setText(i18n("&Bookmarks"));
     auto bookmarks = new KJotsBookmarks(m_collectionView->selectionModel(), this);
     connect(bookmarks, &KJotsBookmarks::openLink, this, &KJotsWidget::openLink);
-    auto bmm = new KBookmarkMenu(
-        KBookmarkManager::managerForFile(
-            QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/kjots/bookmarks.xml"),
-            QStringLiteral("kjots")),
-        bookmarks, bookmarkMenu->menu());
-    // "Add bookmark" and "make text bold" actions have conflicting shortcuts (ctrl + b)
-    // Make add_bookmark use ctrl+shift+b to resolve that.
+    m_bookmarkManager = new KBookmarkManager(
+        QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) +
+        QStringLiteral("/kjots/bookmarks.xml"), this);
+    auto bmm = new KBookmarkMenu(m_bookmarkManager, bookmarks,
+                                 bookmarkMenu->menu());
+
+    // "Add bookmark" and "make text bold" actions have conflicting shortcuts
+    // (ctrl + b) Make add_bookmark use ctrl+shift+b to resolve that.
     action = bmm->addBookmarkAction();
     actionCollection->addAction(QStringLiteral("add_bookmark"), action);
     actionCollection->setDefaultShortcut(action, Qt::CTRL | Qt::SHIFT | Qt::Key_B);
@@ -503,8 +494,8 @@ void KJotsWidget::delayedInitialization()
     KActionCollection *actionCollection = m_xmlGuiClient->actionCollection();
 
     // Actions for a single item selection.
-    anySelectionActions = { actionCollection->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Find))),
-                            actionCollection->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Print))),
+    anySelectionActions = { actionCollection->action(KStandardAction::name(KStandardAction::Find)),
+                            actionCollection->action(KStandardAction::name(KStandardAction::Print)),
                             actionCollection->action(QStringLiteral("save_to")) };
 
     updateMenu();
@@ -533,7 +524,7 @@ void KJotsWidget::updateMenu()
 
     // Rename is available only when single something is selected
     m_xmlGuiClient->actionCollection()
-            ->action(QString::fromLatin1(KStandardAction::name(KStandardAction::RenameFile)))
+            ->action(KStandardAction::name(KStandardAction::RenameFile))
             ->setEnabled((itemsSelected == 1) || (m_collectionView->hasFocus() && collectionsSelected == 1));
 
     // Actions available when at least something is shown
@@ -549,11 +540,7 @@ void KJotsWidget::configure()
     }
     auto* dialog = new KConfigDialog(this, QStringLiteral("kjotssettings"), KJotsSettings::self());
     auto configMisc = new KJotsConfigMisc(dialog);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    dialog->addPage(configMisc, i18nc("@title:window config dialog page", "Misc"), QStringLiteral("preferences-other"));
-#else
     dialog->addPage(configMisc->widget(), i18nc("@title:window config dialog page", "Misc"), QStringLiteral("preferences-other"));
-#endif
     connect(dialog, &KConfigDialog::settingsChanged, this, &KJotsWidget::updateConfiguration);
     dialog->show();
 }
@@ -589,19 +576,11 @@ QString KJotsWidget::renderSelectionTo(const QString &theme, const QString &temp
     }
     QHash<QString, QVariant> hash = {{QStringLiteral("entities"), objectList},
                                      {QStringLiteral("i18n_TABLE_OF_CONTENTS"), i18nc("Header for 'Table of contents' section of rendered output", "Table of contents")}};
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Context c(hash);
-#else
     KTextTemplate::Context c(hash);
-#endif
 
     const QString currentTheme = m_loader->themeName();
     m_loader->setTheme(theme);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Template t = m_templateEngine->loadByName(templ);
-#else
     KTextTemplate::Template t = m_templateEngine->loadByName(templ);
-#endif
     const QString result = t->render(&c);
     m_loader->setTheme(currentTheme);
     return result;
@@ -779,6 +758,7 @@ void KJotsWidget::openLink(const QUrl &url)
             // Mapping idx to item view model
             idx = m_collectionSelectionProxyModel->mapFromSource(idx);
             idx = m_itemModel->mapFromSource(idx);
+            idx = m_itemSortModel->mapFromSource(idx);
             m_itemView->selectionModel()->select(idx, QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
         }
     } else {
@@ -786,3 +766,5 @@ void KJotsWidget::openLink(const QUrl &url)
         job->start();
     }
 }
+
+#include "moc_kjotswidget.cpp"
