@@ -14,14 +14,8 @@
 #include <QItemSelectionModel>
 #include <QTimer>
 
-#include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/Collection>
 #include <Akonadi/Item>
-#else
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
-#endif
 
 class KJob;
 
